@@ -4,7 +4,7 @@
 ###############################################################################
 
 library('httr') # for access to the HTTP header
-library('RJSONIO') # for parsing data types from Socrata
+library('jsonlite') # for parsing data types from Socrata
 
 #' Time-stamped message
 #'
@@ -76,17 +76,17 @@ fieldName <- function(humanName) {
 
 #' Convert Socrata calendar_date string to POSIX
 #'
-#' @param x char in Socrata calendar_date format
+#' @param x character vector in one of two Socrata calendar_date formats
 #' @return a POSIX date
 #' @export
 #' @author Hugh J. Devlin, Ph. D. \email{Hugh.Devlin@@cityofchicago.org}
 posixify <- function(x) {
 	x <- as.character(x)
 	# Two calendar date formats supplied by Socrata
-	if(regexpr("^[[:digit:]]{1,2}/[[:digit:]]{1,2}/[[:digit:]]{4}$", x[1])[1] == 1) 
-		strptime(x, format="%m/%d/%Y")
+	if(any(regexpr("^[[:digit:]]{1,2}/[[:digit:]]{1,2}/[[:digit:]]{4}$", x[1])[1] == 1))
+		strptime(x, format="%m/%d/%Y") # short date format
 	else
-		strptime(x, format="%m/%d/%Y %I:%M:%S %p")
+		strptime(x, format="%m/%d/%Y %I:%M:%S %p") # long date-time format
 }
 
 # Wrap httr GET in some diagnostics
@@ -101,7 +101,7 @@ getResponse <- function(url) {
 	status <- http_status(response)
 	if(response$status_code != 200) {
 		msg <- paste("Error in httr GET:", response$status_code, response$headers$statusmessage, url)
-		if(response$headers$`content-length` > 0) {
+		if(!is.null(response$headers$`content-length`) && (response$headers$`content-length` > 0)) {
 			details <- content(response)
 			msg <- paste(msg, details$code[1], details$message[1])	
 		}
@@ -162,7 +162,7 @@ getSodaTypes <- function(response) {
 #' @export
 #' @author Hugh J. Devlin, Ph. D. \email{Hugh.Devlin@@cityofchicago.org}
 #' @examples
-#' df <- read.socrata("http://soda.demo.socrata.com/resource/4334-bgaj.csv")
+#' df <- read.socrata("https://soda.demo.socrata.com/resource/4334-bgaj.csv")
 read.socrata <- function(url) {
 	validUrl <- validateUrl(url) # check url syntax, allow human-readable Socrata url
 	parsedUrl <- parse_url(validUrl)
